#
# spec file for package Coin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 80
%bcond_with docs

Name:           Coin4
Version:        4.0.3
Release:        1.2
Summary:        Scene-graph based retain-mode 3D graphics library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/coin3d/coin/wiki
Source0:        https://github.com/coin3d/coin/releases/download/v%{version}/coin-%{version}-src.tar.gz
# PATCH-FIX-OPENSUSE -- direct GLX usage causes problems on Wayland (taken from Fedora)
Patch2:         coin-no_glx.patch
BuildRequires:  c++_compiler
BuildRequires:  cmake
%if %{with docs}
BuildRequires:  doxygen
BuildRequires:  graphviz
%endif
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  openal-soft-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(x11)

%description
Coin is a scene-graph based, retain-mode, rendering and model
manipulation C++ class library that uses OpenGL for its 3D graphics.
Coin is compatible to Open Inventor 2.1 and also has support for 3D
sound, GLSL shaders, and additional file formats like VRML97.

%package devel
Summary:        Development files for Coin, a 3D graphics library
Group:          Development/Libraries/C and C++
Requires:       fontconfig-devel
Requires:       freetype2-devel
Requires:       libCoin%{soname} = %{version}
Requires:       openal-soft-devel
Requires:       zlib-devel
Requires:       pkgconfig(bzip2)
Requires:       pkgconfig(dri)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Requires:       pkgconfig(x11)
Conflicts:      Coin-devel < 4.0.0

%description devel
Coin is a scene-graph based, retain-mode, rendering and model
manipulation C++ class library that uses OpenGL for its 3D graphics.
Coin is compatible to Open Inventor 2.1 and also has support for 3D
sound, GLSL shaders, and additional file formats like VRML97.

This subpackage contains libraries and header files for developing
applications that want to make use of Coin.

%package devel-doc
Summary:        Development documentation for Coin
Group:          Documentation/HTML

%description devel-doc
Coin is a scene-graph based, retain-mode, rendering and model
manipulation C++ class library.

This package contains the API and other development documentation.

%package -n libCoin%{soname}
Summary:        Scene-graph based retain-mode 3D graphics library
Group:          System/Libraries

%description -n libCoin%{soname}
Coin is a scene-graph based, retain-mode, rendering and model
manipulation C++ class library that uses OpenGL for its 3D graphics.
Coin is compatible to Open Inventor 2.1 and also has support for 3D
sound, GLSL shaders, and additional file formats like VRML97.

%prep
%setup -q -n coin
%autopatch -p1
sed -i '/^#include <Inventor\/C\/basic.h>$/i #include <Inventor/C/errors/debugerror.h>' include/Inventor/SbBasic.h

%build
# DATADIR must be relative to _prefix, and the "4" is added automatically
# default __builddir clashes with existing "build" dir
%global __builddir my_build
%cmake \
    -DCMAKE_INSTALL_DOCDIR=%{_docdir}/Coin \
    -DCMAKE_INSTALL_DATADIR=share/Coin \
    -DHAVE_MULTIPLE_VERSION:BOOL=ON \
    -DCOIN_BUILD_SHARED_LIBS:BOOL=ON \
    -DCOIN_BUILD_TESTS:BOOL=ON \
    %{?with_docs:-DCOIN_BUILD_DOCUMENTATION:BOOL=ON} \
    %{!?with_docs:-DCOIN_BUILD_DOCUMENTATION:BOOL=OFF} \
    -DCOIN_THREADSAFE:BOOL=ON \
    -DUSE_EXTERNAL_EXPAT:BOOL=ON \
    -DFONTCONFIG_RUNTIME_LINKING:BOOL=OFF \
    -DFREETYPE_RUNTIME_LINKING:BOOL=OFF \
    -DLIBBZIP2_RUNTIME_LINKING:BOOL=OFF \
    -DOPENAL_RUNTIME_LINKING:BOOL=OFF \
    -DSIMAGE_RUNTIME_LINKING:BOOL=OFF \
    -DZLIB_RUNTIME_LINKING:BOOL=OFF \
    -DGLU_RUNTIME_LINKING:BOOL=OFF \
    %{nil}
%cmake_build

%install
%cmake_install

# Remove disfunct coin-config (missing *.cfg file)
rm %{buildroot}%{_bindir}/coin-config

# Remove build configuration
rm -Rf %{buildroot}%{_datadir}/Coin/conf

%fdupes %{buildroot}/%{_prefix}

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest

%post -n libCoin%{soname} -p /sbin/ldconfig
%postun -n libCoin%{soname} -p /sbin/ldconfig

%files -n libCoin%{soname}
%license COPYING
%{_datadir}/%{name}
%{_libdir}/libCoin.so.%{soname}*

%files devel
%doc AUTHORS ChangeLog FAQ NEWS README.md RELNOTES THANKS
%license COPYING FAQ.legal
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/Inventor/
%{_includedir}/%{name}/SoDebug.h
%{_includedir}/%{name}/SoWinEnterScope.h
%{_includedir}/%{name}/SoWinLeaveScope.h
%{_libdir}/pkgconfig/Coin.pc
%{_libdir}/cmake/Coin*
%{_libdir}/libCoin.so

%if %{with docs}
%files devel-doc
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/html
%endif

%changelog
* Sat Jan 18 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.0.3:
  * For details, see
    https://github.com/coin3d/coin/blob/v4.0.3/NEWS
* Sat Jan  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.0.2:
  * Restore ABI compatibility to version 4.0.0
- Update to version 4.0.1:
  * For details, see
    https://github.com/coin3d/coin/blob/Coin-4.0.0/NEWS
- Drop upstream patches:
  * Coin4-versioned.patch
  * 0001-Add-missing-libdl-link-library-for-dlopen.patch
* Mon Feb 21 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.0.0:
  * For details, see
    https://github.com/coin3d/coin/blob/Coin-4.0.0/NEWS
- Update License tag, relicensed as BSD-3-Clause
- Drop obsolete patches:
  * 0012-memhandler-initialization.patch
  * Coin.patch
- Replace Coin60.patch with Coin4-versioned.patch
- Split API documentation from devel package
- Add 0001-Add-missing-libdl-link-library-for-dlopen.patch
* Tue Dec 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Explicitly request system libexpat. The bundled expat 2.0.1 has
  known vulnerabilities, and also causes crashes in e.g. FreeCADs
  SVG import due to using incompatible expat versions in use at
  the same time (https://tracker.freecadweb.org/view.php?id=3307).
  * 0001-Actually-link-to-system-expat.patch
- Cleanup spec file:
  * Update Homepage URL
  * Remove Source URL, bitbucket download is no longer functional
  * Use %%license, %%make_build, %%make_install macros
* Sun Jul 23 2017 olaf@aepfle.de
- Fix invalid C++ with Coin.patch
* Fri Apr 14 2017 lnussel@suse.de
- Remove obsolete 13.2 patch fix-freetype2-includes.patch, fixes
  build for 42.3
* Thu Mar  9 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Sun Oct 30 2016 jengelh@inai.de
- Redo description from in-tarball README
- Run fdupes over entire package
* Mon Aug 15 2016 adrian@suse.de
- install data files into versioned directory
* Sat Jul 30 2016 wk@ire.pw.edu.pl
- Do not use freetype2 patch on Leap 42.2
* Sat Jul 30 2016 adrian@suse.de
- fix file conflict with qwt-devel-doc (deprecated man page)
* Sat Jul  9 2016 dev@stellardeath.org
- Import bugfix from Fedora that corrects a segfault that appears
  with GCC-6 due to an error in Coin,
  * 0012-memhandler-initialization.patch
  More information about this available at
    https://bugzilla.redhat.com/show_bug.cgi?id=1323159#c43
* Tue Jul  5 2016 adrian@suse.de
- fix download url of source tar ball
* Sat Mar 26 2016 wk@ire.pw.edu.pl
- Do not use freetype2 patch on Tumbleweed
* Sun Mar  9 2014 tittiatcoke@gmail.com
- Drop patch gcc-4.7.patch due to upstream inclusion
- Added patch fix-freetype2-includes.patch to fix
  build issues with freetype2
* Sun Oct 28 2012 asterios.dramis@gmail.com
- Added bzip2 as build requirement (needed for Factory).
* Tue Sep 25 2012 asterios.dramis@gmail.com
- Use pkgconfig(...) for Mesa and xorg-x11 build requirements. This fixes also
  compilation in Factory due to the Mesa package changes (with the addition of
  pkgconfig(dri) as build requirement).
* Sat Apr 28 2012 asterios.dramis@gmail.com
- Added the following devel packages as requirements of Coin-devel:
  Mesa-libGL-devel, Mesa-libGLU-devel, fontconfig-devel, freetype2-devel,
  libICE-devel, libX11-devel, libXt-devel, openal-soft-devel and zlib-devel.
* Fri Apr 27 2012 asterios.dramis@gmail.com
- Added a patch to fix compilation with gcc-4.7 (based on a patch from Fedora).
- Link to the needed libraries during compilation instead of using runtime
  linking. This added the following build dependencies:
  Mesa-libGL-devel, Mesa-libGLU-devel, fontconfig-devel, freetype2-devel,
  libICE-devel, libX11-devel, libXt-devel, openal-soft-devel and zlib-devel.
- Removed freeglut-devel dependency (not needed).
- Build development documentation (with doxygen).
- Changed License to GPL-2.0.
- Remove build time references so build-compare can do its work.
- Use the correct arch libdir in Coin.pc and coin-default.cfg files.
* Fri Dec 10 2010 andrea@links2linux.de
- new upstream version 3.1.3
* Sat Sep 26 2009 Andrea Florio <andrea@links2linux.de> 3.1.1
- new upstream version
* Sun Sep 28 2008 Andrea Florio <andrea@links2linux.de>
- complete spec rewrite
* Sun Nov 18 2007 Michal Vyskocil <mvyskocil@suse.cz>
- First release for OpenSuse Build Service
